==> jc-1.4.0.tar.gz: java/lang/reflect/GenericSignatureFormatError.h <==
// public class java.lang.reflect.GenericSignatureFormatError

// class file dependencies
// @dep_class c933004fd5a6148 java_lang_ClassFormatError
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 3746e17e005bda9e java_lang_LinkageError
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 24290eed6607b78d java_lang_reflect_GenericSignatureFormatError

// header file dependencies
// @dep_header java_lang_ClassFormatError

#include "java/lang/ClassFormatError.h"

#ifndef _JC_java_lang_reflect_GenericSignatureFormatError_H_
#define _JC_java_lang_reflect_GenericSignatureFormatError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_lang_reflect_GenericSignatureFormatError$sub_refs	_jc_java_lang_reflect_GenericSignatureFormatError$sub_refs;
typedef struct _jc_java_lang_reflect_GenericSignatureFormatError$sub_nonrefs	_jc_java_lang_reflect_GenericSignatureFormatError$sub_nonrefs;
typedef struct _jc_java_lang_reflect_GenericSignatureFormatError$refs	_jc_java_lang_reflect_GenericSignatureFormatError$refs;
typedef struct _jc_java_lang_reflect_GenericSignatureFormatError$nonrefs	_jc_java_lang_reflect_GenericSignatureFormatError$nonrefs;
typedef struct _jc_java_lang_reflect_GenericSignatureFormatError$object	_jc_java_lang_reflect_GenericSignatureFormatError$object;

typedef const struct _jc_java_lang_reflect_GenericSignatureFormatError$vmethods	_jc_java_lang_reflect_GenericSignatureFormatError$vmethods;
typedef const struct _jc_java_lang_reflect_GenericSignatureFormatError$vtable	_jc_java_lang_reflect_GenericSignatureFormatError$vtable;
typedef const struct _jc_java_lang_reflect_GenericSignatureFormatError$vtype	_jc_java_lang_reflect_GenericSignatureFormatError$vtype;

// Constructors
extern void _jc_java_lang_reflect_GenericSignatureFormatError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_reflect_GenericSignatureFormatError$object *);

// Virtual methods structure
struct _jc_java_lang_reflect_GenericSignatureFormatError$vmethods {
};

// Vtable
struct _jc_java_lang_reflect_GenericSignatureFormatError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_LinkageError$vmethods	java_lang_LinkageError;
	_jc_java_lang_ClassFormatError$vmethods	java_lang_ClassFormatError;
	_jc_java_lang_reflect_GenericSignatureFormatError$vmethods	java_lang_reflect_GenericSignatureFormatError;
};

// Vtype
struct _jc_java_lang_reflect_GenericSignatureFormatError$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_GenericSignatureFormatError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_GenericSignatureFormatError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_GenericSignatureFormatError$refs {
    _jc_java_lang_reflect_GenericSignatureFormatError$sub_refs	java_lang_reflect_GenericSignatureFormatError;
    _jc_java_lang_ClassFormatError$sub_refs	java_lang_ClassFormatError;
    _jc_java_lang_LinkageError$sub_refs	java_lang_LinkageError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_GenericSignatureFormatError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_GenericSignatureFormatError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_LinkageError$sub_nonrefs	java_lang_LinkageError;
    _jc_java_lang_ClassFormatError$sub_nonrefs	java_lang_ClassFormatError;
    _jc_java_lang_reflect_GenericSignatureFormatError$sub_nonrefs	java_lang_reflect_GenericSignatureFormatError;
};

// Object instance structure
struct _jc_java_lang_reflect_GenericSignatureFormatError$object {
	_jc_java_lang_reflect_GenericSignatureFormatError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_GenericSignatureFormatError$vtype	*vtype;
	_jc_java_lang_reflect_GenericSignatureFormatError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_GenericSignatureFormatError$vtype _jc_java_lang_reflect_GenericSignatureFormatError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_GenericSignatureFormatError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_GenericSignatureFormatError$class_object;

#endif	/* _JC_java_lang_reflect_GenericSignatureFormatError_H_ */

==> jc-1.4.6.tar.gz: java/lang/reflect/GenericSignatureFormatError.h <==
// public class java.lang.reflect.GenericSignatureFormatError

// class file dependencies
// @dep_class c933004fd5a6148 java_lang_ClassFormatError
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 3746e17e005bda9e java_lang_LinkageError
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 24290eed6607b78d java_lang_reflect_GenericSignatureFormatError

// header file dependencies
// @dep_header java_lang_ClassFormatError

#include "java/lang/ClassFormatError.h"

#ifndef _JC_java_lang_reflect_GenericSignatureFormatError_H_
#define _JC_java_lang_reflect_GenericSignatureFormatError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_lang_reflect_GenericSignatureFormatError$sub_refs	_jc_java_lang_reflect_GenericSignatureFormatError$sub_refs;
typedef struct _jc_java_lang_reflect_GenericSignatureFormatError$sub_nonrefs	_jc_java_lang_reflect_GenericSignatureFormatError$sub_nonrefs;
typedef struct _jc_java_lang_reflect_GenericSignatureFormatError$refs	_jc_java_lang_reflect_GenericSignatureFormatError$refs;
typedef struct _jc_java_lang_reflect_GenericSignatureFormatError$nonrefs	_jc_java_lang_reflect_GenericSignatureFormatError$nonrefs;
typedef struct _jc_java_lang_reflect_GenericSignatureFormatError$object	_jc_java_lang_reflect_GenericSignatureFormatError$object;

typedef const struct _jc_java_lang_reflect_GenericSignatureFormatError$vmethods	_jc_java_lang_reflect_GenericSignatureFormatError$vmethods;
typedef const struct _jc_java_lang_reflect_GenericSignatureFormatError$vtable	_jc_java_lang_reflect_GenericSignatureFormatError$vtable;
typedef const struct _jc_java_lang_reflect_GenericSignatureFormatError$vtype	_jc_java_lang_reflect_GenericSignatureFormatError$vtype;

// Constructors
extern void _jc_java_lang_reflect_GenericSignatureFormatError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_reflect_GenericSignatureFormatError$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_reflect_GenericSignatureFormatError$vmethods {
};

// Vtable
struct _jc_java_lang_reflect_GenericSignatureFormatError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_LinkageError$vmethods	java_lang_LinkageError;
	_jc_java_lang_ClassFormatError$vmethods	java_lang_ClassFormatError;
	_jc_java_lang_reflect_GenericSignatureFormatError$vmethods	java_lang_reflect_GenericSignatureFormatError;
};

// Vtype
struct _jc_java_lang_reflect_GenericSignatureFormatError$vtype {
	_jc_type			type;
	_jc_java_lang_reflect_GenericSignatureFormatError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_reflect_GenericSignatureFormatError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_reflect_GenericSignatureFormatError$refs {
    _jc_java_lang_reflect_GenericSignatureFormatError$sub_refs	java_lang_reflect_GenericSignatureFormatError;
    _jc_java_lang_ClassFormatError$sub_refs	java_lang_ClassFormatError;
    _jc_java_lang_LinkageError$sub_refs	java_lang_LinkageError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_reflect_GenericSignatureFormatError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_reflect_GenericSignatureFormatError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_LinkageError$sub_nonrefs	java_lang_LinkageError;
    _jc_java_lang_ClassFormatError$sub_nonrefs	java_lang_ClassFormatError;
    _jc_java_lang_reflect_GenericSignatureFormatError$sub_nonrefs	java_lang_reflect_GenericSignatureFormatError;
};

// Object instance structure
struct _jc_java_lang_reflect_GenericSignatureFormatError$object {
	_jc_java_lang_reflect_GenericSignatureFormatError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_reflect_GenericSignatureFormatError$vtype	*vtype;
	_jc_java_lang_reflect_GenericSignatureFormatError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_reflect_GenericSignatureFormatError$vtype _jc_java_lang_reflect_GenericSignatureFormatError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_reflect_GenericSignatureFormatError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_reflect_GenericSignatureFormatError$class_object;

#endif	/* _JC_java_lang_reflect_GenericSignatureFormatError_H_ */
